Learn R Programming

gamlss.data (version 4.3-4)

film90: Film revenue data for the 1990's

Description

Data from film revenues from the 1990s'.

Usage

data(film90)

Arguments

Format

A data frame with 4031 observations on the following 14 variables.
time
Date of release of the film
year
the year of release of the film
month
a factor, the month of release of the film
title
a factor indicating the tittle of the film
borev0
real box office revenues, calculated in 1987 prices
lborev0
the log of real box office revenues, calculated in 1987 prices
nosc
the number of screens
lnosc
the log of the number of screens
boopen
box office opening revenues calculated in 1987 prices
lboopen
the log of box office opening revenues calculated in 1987 prices
borev1
the box office revenues after the first week, borev0-boopen
lborev1
the log of box office revenues after the first week
dist
a factor indicating whether Independent or Major distributor
whetherCost
a factor with levels 0 1 indication whether the original data has the cost of the film to make

Data collected by Prof. John Sedgwick

Details

Those data are analysed in Voudouris et. al. (2011)

References

Gilchrist, R., Rigby, R., Sedgwick, J., Stasinopoulos, S., Voudouris, V. (2011) Forecasting film revenues using GAMLSS, in Proceedings of the 26th International Workshop on Statistical Modeling ed: Conesa, D., Forte, A., Lopez-Quilez, A., Munoz, F., 263-268, Valencia, Spain.

Voudouris V., Gilchrist R., Rigby R., Sedgwick J. and Stasinopoulos D. (2011) Modelling skewness and kurtosis with the BCPE density in GAMLSS. Journal of Applied Statistics

Examples

Run this code
data(film90)

Run the code above in your browser using DataLab