Description Usage Format Source References Examples
There two data sets contain data used in Hodges (1998). In addition to the data used in that manuscript, it contains other data items.
The original data consists of two matrices of dimensions of 341x6 and a 45x4 respectively.
The first matrix hodges describes plans. The information for each plan is:
the state, a two-character code that identifies plans within state, the total premium for
an individual, the total premium for a family, the total enrollment of
federal employees as individuals, and the total enrollment of federal
employees as families.
The second matrix, hodges, describes states. The information for each state is:
its two-letter abbreviation, the state average expenses per admission
(from American Medical Association 1991 Annual Survey of Hospitals),
population (1990 Census), and the region (from the Marion Merrill Dow
Managed Care Digest 1991).
The Hodges manuscript used these variables: Plan level: individual premium, individual enrollment. State level: expenses per admission, region.
1 |
Two data frames the first with 341 observations on the following 6 variables.
statea factor with 45 levels AL AZ CA CO
CT DC DE FL
GA GU HI IA
ID IL IN KS
KY LA MA MD
ME MI MN MO
NC ND NE NH
NJ NM NV NY
OH OK OR PA
PR RI SC TN
TX UT VA WA
WI
plana two-character code that identifies plans within state declared here as factor with 325 levals.
prinda numeric vector showing the total premium for an individual
prfama numeric vector showing the total premium for a family
eninda numeric vector showing the total enrollment of federal employees as individuals
enfama numeric vector showing the total enrollment of federal employees as families.
and the second with 45 observations on the following 4 variables
Statea factor with levels same as state above
expea numeric vector showing the state average expenses per admission (from American Medical Association 1991 Annual Survey of Hospitals)
popa numeric vector shoing the population (1990 Census)
region the region (from the Marion Merrill Dow Managed Care Digest 1991),
a factor with levels MA MT NC NE PA SA SC
http://www.biostat.umn.edu/~hodges/
Hodges, J. S. (1998). Some algebra and geometry for hierarchical models, applied to diadnostics. J. R. Statist. Soc. B., 60 pp 497:536.
1 2 3 4 5 6 |
Attaching package: 'gamlss.data'
The following object is masked from 'package:datasets':
sleep
'data.frame': 341 obs. of 6 variables:
$ state: Factor w/ 45 levels "AL","AZ","CA",..: 1 1 1 1 1 1 1 2 2 2 ...
$ plan : Factor w/ 325 levels "11","12","15",..: 39 77 216 218 221 223 237 4 37 38 ...
$ prind: num 236 168 170 181 164 ...
$ prfam: num 470 429 411 424 417 ...
$ enind: num 93 824 483 174 285 ...
$ enfam: num 321 1508 789 338 438 ...
'data.frame': 45 obs. of 4 variables:
$ State : Factor w/ 45 levels "AL","AZ","CA",..: 1 2 3 4 5 6 7 8 9 10 ...
$ expe : num 4455 5212 6169 5449 6696 ...
$ pop : num 4041 3665 29760 3294 3287 ...
$ region: Factor w/ 7 levels "MA","MT","NC",..: 7 2 5 2 4 6 6 6 6 5 ...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.