Learn R Programming

gamlss.data (version 4.3-2)

meta: A Meta Analysis on Smoking Cessation

Description

The data here are coming from a statistical meta analysis problem. In meta analysis we combine the evidence from different studies to obtain an overall treatment effect. The data from Silagy et al. (2003) consist of different clinical trials of nicotine replacement therapy for smoking cessation. In each trial the patient was randomized into a treatment or control group. The treatment group were given a nicotine gum. In the majority of studies the control group receive the same appearance gum but without the ingredients but in some they were given no gum. The outcome, whether the participant is smoking or not, was observed after six months. The data were previously analysed by Aitkin (1999) and by Skrondal and Rabe-Hesketh (2004).

Usage

data("meta")

Arguments

docType

data

References

Aitkin. M. Meta-analysis by random effect modelling in generalised linear models. Statistics in Medicine, 18, 2343-2351, 1999

Skrondal A. and Rabe-Hesketh S. Generalized Latent Variable modelling. Chapman & Hall, (2004).

Examples

Run this code
data(meta)
## maybe str(meta) ; plot(meta) ...

Run the code above in your browser using DataLab