Learn R Programming

gamlss.data (version 4.3-2)

respInf: Respiratory Infection in Indonesian Children.

Description

This is cohort study of 275 Indonesian preschool children, ($J=1,2, ...,275$), examined on up to six, consecutive quarters for the presence of respiratory infection. Sommer et al. (1983) describe the study, while Zeger and Karim (1991) and Diggle et al (2002) among others analyzed it. The data were also analyzed by Skrondal and Rabe-Hesketh (2004).

Usage

data("respInf")

Arguments

docType

data

References

Diggle, P. J., Heagerty, P., Liang, K. Y. and Zeger S. L.Analysis of Longitudinal Data, 2nd ed. Oxford University Press, Oxford, 2002.

Sommer, Alfred, et al. Increased mortality in children with mild vitamin A deficiency. The Lancet 322 83:50 (1983): 585-588.

Skrondal A. and Rabe-Hesketh S. Genaralized Latent Variable modelling. Chapman & Hall, (2004).

Zeger S. L and Karim M. R. Generalized linear models with random effects: a gibbs sampling approach. J. Am. Statist. Ass., 86, 79-95, 1991.

Examples

Run this code
data(respInf)
## maybe str(respInf) ; plot(respInf) ...

Run the code above in your browser using DataLab