Learn R Programming

gamlss.data (version 4.2-7)

species: The Fish Species Data files for GAMLSS

Description

species: The number of different fish species (y=fish) was recorded for 70 lakes of the world together with explanatory variable x=log(lake) area. The data are given and analyzed by Stein and Juritz (1988).

Usage

data(species)

Arguments

docType

data

Details

Data sets usefull for the GAMLSS booklet

References

Stein, G. Z. and Juritz, J. M. (1988). Linear models with an inverse Gaussian-Poisson error distribution. Communications in Statistics- Theory and Methods, 17, 557-571.

Examples

Run this code
data(species)
with(species, plot(fish~log(lake)))

Run the code above in your browser using DataLab